# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import procurement_group_pb2 as v1_dot_stock_dot_procurement__group__pb2


class ProcurementGroupServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProcurementGroupCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupCreate",
            request_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateResponse.FromString,
        )
        self.ProcurementGroupRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupRead",
            request_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadResponse.FromString,
        )
        self.ProcurementGroupUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupUpdate",
            request_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateResponse.FromString,
        )
        self.ProcurementGroupDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupDelete",
            request_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteResponse.FromString,
        )


class ProcurementGroupServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ProcurementGroupCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ProcurementGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ProcurementGroupCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupCreate,
            request_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateResponse.SerializeToString,
        ),
        "ProcurementGroupRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupRead,
            request_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadResponse.SerializeToString,
        ),
        "ProcurementGroupUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupUpdate,
            request_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateResponse.SerializeToString,
        ),
        "ProcurementGroupDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupDelete,
            request_deserializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ProcurementGroupService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ProcurementGroupCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupCreate",
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateRequest.SerializeToString,
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupRead",
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadRequest.SerializeToString,
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupUpdate",
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupService/ProcurementGroupDelete",
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            v1_dot_stock_dot_procurement__group__pb2.ProcurementGroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11\x63ommon/base.proto\x12\x1cpro.omni.oms.api.common.base\x1a\x1fgoogle/protobuf/timestamp.proto")\n\x06Object\x12\x11\n\tcode_name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"\x1d\n\x07GroupBy\x12\x12\n\nname_field\x18\x01 \x01(\t"x\n\x06SortBy\x12\x12\n\nname_field\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.pro.omni.oms.api.common.base.SortBy.SortType"\x1d\n\x08SortType\x12\x07\n\x03\x41SC\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01"\x1c\n\x06\x46ields\x12\x12\n\nname_field\x18\x01 \x03(\t"\x18\n\x06\x46ilter\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t"*\n\tPaginated\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05"\x8c\x01\n\x08LinkPage\x12=\n\x04type\x18\x01 \x01(\x0e\x32/.pro.omni.oms.api.common.base.LinkPage.LinkType\x12\x0c\n\x04link\x18\x02 \x01(\t"3\n\x08LinkType\x12\x08\n\x04NEXT\x10\x00\x12\x08\n\x04PREV\x10\x01\x12\x08\n\x04LAST\x10\x02\x12\t\n\x05\x46IRST\x10\x03"\x82\x01\n\x08MetaData\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05\x63ount\x18\x04 \x01(\x05\x12\x39\n\tlink_page\x18\x05 \x03(\x0b\x32&.pro.omni.oms.api.common.base.LinkPage"_\n\x10ResponseStandard\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bstatus_code\x18\x03 \x01(\x05\x12\x14\n\x0cmessage_code\x18\x04 \x01(\t"\xd9\x01\n\x0bObjectAudit\x12\x12\n\ncreated_by\x18\x01 \x01(\t\x12\x12\n\nupdated_by\x18\x02 \x01(\t\x12\x12\n\ndeleted_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\'\n\x07\x43ontext\x12\x0e\n\x06tenant\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t"*\n\x0eObjectResponse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\tb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.base_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_OBJECT"]._serialized_start = 84
    _globals["_OBJECT"]._serialized_end = 125
    _globals["_GROUPBY"]._serialized_start = 127
    _globals["_GROUPBY"]._serialized_end = 156
    _globals["_SORTBY"]._serialized_start = 158
    _globals["_SORTBY"]._serialized_end = 278
    _globals["_SORTBY_SORTTYPE"]._serialized_start = 249
    _globals["_SORTBY_SORTTYPE"]._serialized_end = 278
    _globals["_FIELDS"]._serialized_start = 280
    _globals["_FIELDS"]._serialized_end = 308
    _globals["_FILTER"]._serialized_start = 310
    _globals["_FILTER"]._serialized_end = 334
    _globals["_PAGINATED"]._serialized_start = 336
    _globals["_PAGINATED"]._serialized_end = 378
    _globals["_LINKPAGE"]._serialized_start = 381
    _globals["_LINKPAGE"]._serialized_end = 521
    _globals["_LINKPAGE_LINKTYPE"]._serialized_start = 470
    _globals["_LINKPAGE_LINKTYPE"]._serialized_end = 521
    _globals["_METADATA"]._serialized_start = 524
    _globals["_METADATA"]._serialized_end = 654
    _globals["_RESPONSESTANDARD"]._serialized_start = 656
    _globals["_RESPONSESTANDARD"]._serialized_end = 751
    _globals["_OBJECTAUDIT"]._serialized_start = 754
    _globals["_OBJECTAUDIT"]._serialized_end = 971
    _globals["_CONTEXT"]._serialized_start = 973
    _globals["_CONTEXT"]._serialized_end = 1012
    _globals["_OBJECTRESPONSE"]._serialized_start = 1014
    _globals["_OBJECTRESPONSE"]._serialized_end = 1056
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/clients/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.clients import address_pb2 as v1_dot_clients_dot_address__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/clients/client.proto\x12"pro.omni.oms.api.v1.clients.client\x1a\x11\x63ommon/base.proto\x1a\x18v1/clients/address.proto"\xd9\x02\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\rtype_document\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x10\n\x08\x64ocument\x18\x04 \x01(\t\x12\x0e\n\x06mobile\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x35\n\x07\x63ountry\x18\x07 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12?\n\taddresses\x18\x08 \x03(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address\x12\x0e\n\x06\x61\x63tive\x18\t \x01(\x08\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x80\x02\n\x13\x43lientCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12;\n\rtype_document\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\x12\x0e\n\x06mobile\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x35\n\x07\x63ountry\x18\x06 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x14\x43lientCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12:\n\x06\x63lient\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.clients.client.Client"\xef\x02\n\x11\x43lientReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n\x12\x43lientReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12;\n\x07\x63lients\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.clients.client.Client"\x89\x01\n\x13\x43lientUpdateRequest\x12:\n\x06\x63lient\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.clients.client.Client\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x14\x43lientUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12:\n\x06\x63lient\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.clients.client.Client"Y\n\x13\x43lientDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x43lientDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa1\x04\n\x0e\x43lientsService\x12\x83\x01\n\x0c\x43lientCreate\x12\x37.pro.omni.oms.api.v1.clients.client.ClientCreateRequest\x1a\x38.pro.omni.oms.api.v1.clients.client.ClientCreateResponse"\x00\x12}\n\nClientRead\x12\x35.pro.omni.oms.api.v1.clients.client.ClientReadRequest\x1a\x36.pro.omni.oms.api.v1.clients.client.ClientReadResponse"\x00\x12\x83\x01\n\x0c\x43lientUpdate\x12\x37.pro.omni.oms.api.v1.clients.client.ClientUpdateRequest\x1a\x38.pro.omni.oms.api.v1.clients.client.ClientUpdateResponse"\x00\x12\x83\x01\n\x0c\x43lientDelete\x12\x37.pro.omni.oms.api.v1.clients.client.ClientDeleteRequest\x1a\x38.pro.omni.oms.api.v1.clients.client.ClientDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.clients.client_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CLIENT"]._serialized_start = 109
    _globals["_CLIENT"]._serialized_end = 454
    _globals["_CLIENTCREATEREQUEST"]._serialized_start = 457
    _globals["_CLIENTCREATEREQUEST"]._serialized_end = 713
    _globals["_CLIENTCREATERESPONSE"]._serialized_start = 716
    _globals["_CLIENTCREATERESPONSE"]._serialized_end = 873
    _globals["_CLIENTREADREQUEST"]._serialized_start = 876
    _globals["_CLIENTREADREQUEST"]._serialized_end = 1243
    _globals["_CLIENTREADRESPONSE"]._serialized_start = 1246
    _globals["_CLIENTREADRESPONSE"]._serialized_end = 1461
    _globals["_CLIENTUPDATEREQUEST"]._serialized_start = 1464
    _globals["_CLIENTUPDATEREQUEST"]._serialized_end = 1601
    _globals["_CLIENTUPDATERESPONSE"]._serialized_start = 1604
    _globals["_CLIENTUPDATERESPONSE"]._serialized_end = 1761
    _globals["_CLIENTDELETEREQUEST"]._serialized_start = 1763
    _globals["_CLIENTDELETEREQUEST"]._serialized_end = 1852
    _globals["_CLIENTDELETERESPONSE"]._serialized_start = 1854
    _globals["_CLIENTDELETERESPONSE"]._serialized_end = 1951
    _globals["_CLIENTSSERVICE"]._serialized_start = 1954
    _globals["_CLIENTSSERVICE"]._serialized_end = 2499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/rule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2
from omni.pro.protos.v1.stock import route_pb2 as v1_dot_stock_dot_route__pb2
from omni.pro.protos.v1.stock import warehouse_pb2 as v1_dot_stock_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/stock/rule.proto\x12\x18pro.omni.oms.api.v1.rule\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17v1/stock/location.proto\x1a\x1bv1/stock/picking_type.proto\x1a\x14v1/stock/route.proto\x1a\x18v1/stock/warehouse.proto"\x90\x04\n\x04Rule\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12I\n\x0cpicking_type\x18\x04 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x42\n\x0clocation_src\x18\x05 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12>\n\x08location\x18\x06 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x16\n\x0eprocure_method\x18\x07 \x01(\t\x12\x35\n\x05route\x18\x08 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route\x12\x41\n\twarehouse\x18\t \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse\x12\x10\n\x08sequence\x18\n \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x82\x02\n\x11RuleCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x03 \x01(\x05\x12\x17\n\x0flocation_src_id\x18\x04 \x01(\x05\x12\x13\n\x0blocation_id\x18\x05 \x01(\x05\x12\x16\n\x0eprocure_method\x18\x06 \x01(\t\x12\x10\n\x08route_id\x18\x07 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12\x10\n\x08sequence\x18\t \x01(\x05\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8d\x01\n\x12RuleCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12,\n\x04rule\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.rule.Rule"\xed\x02\n\x0fRuleReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc7\x01\n\x10RuleReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12-\n\x05rules\x18\x03 \x03(\x0b\x32\x1e.pro.omni.oms.api.v1.rule.Rule"y\n\x11RuleUpdateRequest\x12,\n\x04rule\x18\x01 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.rule.Rule\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8d\x01\n\x12RuleUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12,\n\x04rule\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.rule.Rule"W\n\x11RuleDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12RuleDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xb3\x03\n\x0bRuleService\x12i\n\nRuleCreate\x12+.pro.omni.oms.api.v1.rule.RuleCreateRequest\x1a,.pro.omni.oms.api.v1.rule.RuleCreateResponse"\x00\x12\x63\n\x08RuleRead\x12).pro.omni.oms.api.v1.rule.RuleReadRequest\x1a*.pro.omni.oms.api.v1.rule.RuleReadResponse"\x00\x12i\n\nRuleUpdate\x12+.pro.omni.oms.api.v1.rule.RuleUpdateRequest\x1a,.pro.omni.oms.api.v1.rule.RuleUpdateResponse"\x00\x12i\n\nRuleDelete\x12+.pro.omni.oms.api.v1.rule.RuleDeleteRequest\x1a,.pro.omni.oms.api.v1.rule.RuleDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.rule_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_RULE"]._serialized_start = 203
    _globals["_RULE"]._serialized_end = 731
    _globals["_RULECREATEREQUEST"]._serialized_start = 734
    _globals["_RULECREATEREQUEST"]._serialized_end = 992
    _globals["_RULECREATERESPONSE"]._serialized_start = 995
    _globals["_RULECREATERESPONSE"]._serialized_end = 1136
    _globals["_RULEREADREQUEST"]._serialized_start = 1139
    _globals["_RULEREADREQUEST"]._serialized_end = 1504
    _globals["_RULEREADRESPONSE"]._serialized_start = 1507
    _globals["_RULEREADRESPONSE"]._serialized_end = 1706
    _globals["_RULEUPDATEREQUEST"]._serialized_start = 1708
    _globals["_RULEUPDATEREQUEST"]._serialized_end = 1829
    _globals["_RULEUPDATERESPONSE"]._serialized_start = 1832
    _globals["_RULEUPDATERESPONSE"]._serialized_end = 1973
    _globals["_RULEDELETEREQUEST"]._serialized_start = 1975
    _globals["_RULEDELETEREQUEST"]._serialized_end = 2062
    _globals["_RULEDELETERESPONSE"]._serialized_start = 2064
    _globals["_RULEDELETERESPONSE"]._serialized_end = 2159
    _globals["_RULESERVICE"]._serialized_start = 2162
    _globals["_RULESERVICE"]._serialized_end = 2597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/location.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/location.proto\x12"pro.omni.oms.api.v1.rules.location\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb8\x01\n\x08Location\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x04 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x84\x01\n\x15LocationCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x03 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16LocationCreateResponse\x12>\n\x08location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13LocationReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x14LocationReadResponse\x12?\n\tlocations\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15LocationUpdateRequest\x12>\n\x08location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16LocationUpdateResponse\x12>\n\x08location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15LocationDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16LocationDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0fLocationService\x12\x89\x01\n\x0eLocationCreate\x12\x39.pro.omni.oms.api.v1.rules.location.LocationCreateRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationCreateResponse"\x00\x12\x83\x01\n\x0cLocationRead\x12\x37.pro.omni.oms.api.v1.rules.location.LocationReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.location.LocationReadResponse"\x00\x12\x89\x01\n\x0eLocationUpdate\x12\x39.pro.omni.oms.api.v1.rules.location.LocationUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationUpdateResponse"\x00\x12\x89\x01\n\x0eLocationDelete\x12\x39.pro.omni.oms.api.v1.rules.location.LocationDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.location_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_LOCATION"]._serialized_start = 115
    _globals["_LOCATION"]._serialized_end = 299
    _globals["_LOCATIONCREATEREQUEST"]._serialized_start = 302
    _globals["_LOCATIONCREATEREQUEST"]._serialized_end = 434
    _globals["_LOCATIONCREATERESPONSE"]._serialized_start = 437
    _globals["_LOCATIONCREATERESPONSE"]._serialized_end = 600
    _globals["_LOCATIONREADREQUEST"]._serialized_start = 603
    _globals["_LOCATIONREADREQUEST"]._serialized_end = 972
    _globals["_LOCATIONREADRESPONSE"]._serialized_start = 975
    _globals["_LOCATIONREADRESPONSE"]._serialized_end = 1196
    _globals["_LOCATIONUPDATEREQUEST"]._serialized_start = 1199
    _globals["_LOCATIONUPDATEREQUEST"]._serialized_end = 1342
    _globals["_LOCATIONUPDATERESPONSE"]._serialized_start = 1345
    _globals["_LOCATIONUPDATERESPONSE"]._serialized_end = 1508
    _globals["_LOCATIONDELETEREQUEST"]._serialized_start = 1510
    _globals["_LOCATIONDELETEREQUEST"]._serialized_end = 1601
    _globals["_LOCATIONDELETERESPONSE"]._serialized_start = 1603
    _globals["_LOCATIONDELETERESPONSE"]._serialized_end = 1702
    _globals["_LOCATIONSERVICE"]._serialized_start = 1705
    _globals["_LOCATIONSERVICE"]._serialized_end = 2276
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import currency_pb2 as _currency_pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as _delivery_locality_pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as _delivery_method_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryPrice(_message.Message):
    __slots__ = [
        "id",
        "name",
        "code",
        "delivery_method",
        "purchase_rank",
        "currency",
        "fixed_price",
        "operator_price",
        "purchase_price",
        "variable_factor",
        "usage",
        "price_by_variable_factor",
        "locality_available",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    PURCHASE_RANK_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    FIXED_PRICE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_PRICE_FIELD_NUMBER: _ClassVar[int]
    PURCHASE_PRICE_FIELD_NUMBER: _ClassVar[int]
    VARIABLE_FACTOR_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    PRICE_BY_VARIABLE_FACTOR_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    delivery_method: _delivery_method_pb2.DeliveryMethod
    purchase_rank: _wrappers_pb2.BoolValue
    currency: _currency_pb2.Currency
    fixed_price: float
    operator_price: str
    purchase_price: float
    variable_factor: str
    usage: str
    price_by_variable_factor: float
    locality_available: _delivery_locality_pb2.DeliveryLocality
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        delivery_method: _Optional[_Union[_delivery_method_pb2.DeliveryMethod, _Mapping]] = ...,
        purchase_rank: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        currency: _Optional[_Union[_currency_pb2.Currency, _Mapping]] = ...,
        fixed_price: _Optional[float] = ...,
        operator_price: _Optional[str] = ...,
        purchase_price: _Optional[float] = ...,
        variable_factor: _Optional[str] = ...,
        usage: _Optional[str] = ...,
        price_by_variable_factor: _Optional[float] = ...,
        locality_available: _Optional[_Union[_delivery_locality_pb2.DeliveryLocality, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "code",
        "delivery_method_id",
        "purchase_rank",
        "currency_id",
        "fixed_price",
        "operator_price",
        "purchase_price",
        "variable_factor",
        "usage",
        "price_by_variable_factor",
        "locality_available_id",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    PURCHASE_RANK_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_ID_FIELD_NUMBER: _ClassVar[int]
    FIXED_PRICE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_PRICE_FIELD_NUMBER: _ClassVar[int]
    PURCHASE_PRICE_FIELD_NUMBER: _ClassVar[int]
    VARIABLE_FACTOR_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    PRICE_BY_VARIABLE_FACTOR_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    delivery_method_id: str
    purchase_rank: _wrappers_pb2.BoolValue
    currency_id: str
    fixed_price: float
    operator_price: str
    purchase_price: float
    variable_factor: str
    usage: str
    price_by_variable_factor: float
    locality_available_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        delivery_method_id: _Optional[str] = ...,
        purchase_rank: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        currency_id: _Optional[str] = ...,
        fixed_price: _Optional[float] = ...,
        operator_price: _Optional[str] = ...,
        purchase_price: _Optional[float] = ...,
        variable_factor: _Optional[str] = ...,
        usage: _Optional[str] = ...,
        price_by_variable_factor: _Optional[float] = ...,
        locality_available_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceCreateResponse(_message.Message):
    __slots__ = ["delivery_price", "response_standard"]
    DELIVERY_PRICE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_price: DeliveryPrice
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_price: _Optional[_Union[DeliveryPrice, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceReadResponse(_message.Message):
    __slots__ = ["delivery_prices", "meta_data", "response_standard"]
    DELIVERY_PRICES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_prices: _containers.RepeatedCompositeFieldContainer[DeliveryPrice]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_prices: _Optional[_Iterable[_Union[DeliveryPrice, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceUpdateRequest(_message.Message):
    __slots__ = ["delivery_price", "context"]
    DELIVERY_PRICE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_price: DeliveryPrice
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_price: _Optional[_Union[DeliveryPrice, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceUpdateResponse(_message.Message):
    __slots__ = ["delivery_price", "response_standard"]
    DELIVERY_PRICE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_price: DeliveryPrice
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_price: _Optional[_Union[DeliveryPrice, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryPriceDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.users import user_pb2 as v1_dot_users_dot_user__pb2


class UsersServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UserCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserCreate",
            request_serializer=v1_dot_users_dot_user__pb2.UserCreateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserCreateResponse.FromString,
        )
        self.UserRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserRead",
            request_serializer=v1_dot_users_dot_user__pb2.UserReadRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserReadResponse.FromString,
        )
        self.UserUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserUpdate",
            request_serializer=v1_dot_users_dot_user__pb2.UserUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserUpdateResponse.FromString,
        )
        self.UserDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserDelete",
            request_serializer=v1_dot_users_dot_user__pb2.UserDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserDeleteResponse.FromString,
        )
        self.UserChangePassword = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserChangePassword",
            request_serializer=v1_dot_users_dot_user__pb2.UserChangePasswordRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserChangePasswordResponse.FromString,
        )
        self.UserChangeEmail = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/UserChangeEmail",
            request_serializer=v1_dot_users_dot_user__pb2.UserChangeEmailRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.UserChangeEmailResponse.FromString,
        )
        self.GroupCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupCreate",
            request_serializer=v1_dot_users_dot_user__pb2.GroupCreateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupCreateResponse.FromString,
        )
        self.GroupRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupRead",
            request_serializer=v1_dot_users_dot_user__pb2.GroupReadRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupReadResponse.FromString,
        )
        self.GroupUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupUpdate",
            request_serializer=v1_dot_users_dot_user__pb2.GroupUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupUpdateResponse.FromString,
        )
        self.GroupDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupDelete",
            request_serializer=v1_dot_users_dot_user__pb2.GroupDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupDeleteResponse.FromString,
        )
        self.ActionCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionCreate",
            request_serializer=v1_dot_users_dot_user__pb2.ActionCreateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.ActionCreateResponse.FromString,
        )
        self.ActionRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionRead",
            request_serializer=v1_dot_users_dot_user__pb2.ActionReadRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.ActionReadResponse.FromString,
        )
        self.ActionUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionUpdate",
            request_serializer=v1_dot_users_dot_user__pb2.ActionUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.ActionUpdateResponse.FromString,
        )
        self.ActionDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionDelete",
            request_serializer=v1_dot_users_dot_user__pb2.ActionDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.ActionDeleteResponse.FromString,
        )
        self.AccessCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessCreate",
            request_serializer=v1_dot_users_dot_user__pb2.AccessCreateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessCreateResponse.FromString,
        )
        self.AccessRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessRead",
            request_serializer=v1_dot_users_dot_user__pb2.AccessReadRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessReadResponse.FromString,
        )
        self.AccessUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessUpdate",
            request_serializer=v1_dot_users_dot_user__pb2.AccessUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessUpdateResponse.FromString,
        )
        self.AccessDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessDelete",
            request_serializer=v1_dot_users_dot_user__pb2.AccessDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessDeleteResponse.FromString,
        )
        self.HasPermission = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/HasPermission",
            request_serializer=v1_dot_users_dot_user__pb2.HasPermissionRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.HasPermissionResponse.FromString,
        )
        self.Login = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/Login",
            request_serializer=v1_dot_users_dot_user__pb2.LoginRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.LoginResponse.FromString,
        )
        self.RefreshToken = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/RefreshToken",
            request_serializer=v1_dot_users_dot_user__pb2.RefreshTokenRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.RefreshTokenResponse.FromString,
        )
        self.AddAccessToGroup = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AddAccessToGroup",
            request_serializer=v1_dot_users_dot_user__pb2.AccessGroupRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessGroupResponse.FromString,
        )
        self.RemoveAccessFromGroup = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/RemoveAccessFromGroup",
            request_serializer=v1_dot_users_dot_user__pb2.AccessGroupRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.AccessGroupResponse.FromString,
        )
        self.AddGroupToUser = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/AddGroupToUser",
            request_serializer=v1_dot_users_dot_user__pb2.GroupUserRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupUserResponse.FromString,
        )
        self.RemoveGroupFromUser = channel.unary_unary(
            "/pro.omni.oms.api.v1.users.user.UsersService/RemoveGroupFromUser",
            request_serializer=v1_dot_users_dot_user__pb2.GroupUserRequest.SerializeToString,
            response_deserializer=v1_dot_users_dot_user__pb2.GroupUserResponse.FromString,
        )


class UsersServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UserCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserChangePassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserChangeEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GroupDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActionCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActionRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActionUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActionDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AccessCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AccessRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AccessUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AccessDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HasPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddAccessToGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RemoveAccessFromGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddGroupToUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RemoveGroupFromUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UsersServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "UserCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UserCreate,
            request_deserializer=v1_dot_users_dot_user__pb2.UserCreateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserCreateResponse.SerializeToString,
        ),
        "UserRead": grpc.unary_unary_rpc_method_handler(
            servicer.UserRead,
            request_deserializer=v1_dot_users_dot_user__pb2.UserReadRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserReadResponse.SerializeToString,
        ),
        "UserUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UserUpdate,
            request_deserializer=v1_dot_users_dot_user__pb2.UserUpdateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserUpdateResponse.SerializeToString,
        ),
        "UserDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UserDelete,
            request_deserializer=v1_dot_users_dot_user__pb2.UserDeleteRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserDeleteResponse.SerializeToString,
        ),
        "UserChangePassword": grpc.unary_unary_rpc_method_handler(
            servicer.UserChangePassword,
            request_deserializer=v1_dot_users_dot_user__pb2.UserChangePasswordRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserChangePasswordResponse.SerializeToString,
        ),
        "UserChangeEmail": grpc.unary_unary_rpc_method_handler(
            servicer.UserChangeEmail,
            request_deserializer=v1_dot_users_dot_user__pb2.UserChangeEmailRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.UserChangeEmailResponse.SerializeToString,
        ),
        "GroupCreate": grpc.unary_unary_rpc_method_handler(
            servicer.GroupCreate,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupCreateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupCreateResponse.SerializeToString,
        ),
        "GroupRead": grpc.unary_unary_rpc_method_handler(
            servicer.GroupRead,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupReadRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupReadResponse.SerializeToString,
        ),
        "GroupUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.GroupUpdate,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupUpdateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupUpdateResponse.SerializeToString,
        ),
        "GroupDelete": grpc.unary_unary_rpc_method_handler(
            servicer.GroupDelete,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupDeleteRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupDeleteResponse.SerializeToString,
        ),
        "ActionCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ActionCreate,
            request_deserializer=v1_dot_users_dot_user__pb2.ActionCreateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.ActionCreateResponse.SerializeToString,
        ),
        "ActionRead": grpc.unary_unary_rpc_method_handler(
            servicer.ActionRead,
            request_deserializer=v1_dot_users_dot_user__pb2.ActionReadRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.ActionReadResponse.SerializeToString,
        ),
        "ActionUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ActionUpdate,
            request_deserializer=v1_dot_users_dot_user__pb2.ActionUpdateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.ActionUpdateResponse.SerializeToString,
        ),
        "ActionDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ActionDelete,
            request_deserializer=v1_dot_users_dot_user__pb2.ActionDeleteRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.ActionDeleteResponse.SerializeToString,
        ),
        "AccessCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AccessCreate,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessCreateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessCreateResponse.SerializeToString,
        ),
        "AccessRead": grpc.unary_unary_rpc_method_handler(
            servicer.AccessRead,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessReadRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessReadResponse.SerializeToString,
        ),
        "AccessUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AccessUpdate,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessUpdateRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessUpdateResponse.SerializeToString,
        ),
        "AccessDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AccessDelete,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessDeleteRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessDeleteResponse.SerializeToString,
        ),
        "HasPermission": grpc.unary_unary_rpc_method_handler(
            servicer.HasPermission,
            request_deserializer=v1_dot_users_dot_user__pb2.HasPermissionRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.HasPermissionResponse.SerializeToString,
        ),
        "Login": grpc.unary_unary_rpc_method_handler(
            servicer.Login,
            request_deserializer=v1_dot_users_dot_user__pb2.LoginRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.LoginResponse.SerializeToString,
        ),
        "RefreshToken": grpc.unary_unary_rpc_method_handler(
            servicer.RefreshToken,
            request_deserializer=v1_dot_users_dot_user__pb2.RefreshTokenRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.RefreshTokenResponse.SerializeToString,
        ),
        "AddAccessToGroup": grpc.unary_unary_rpc_method_handler(
            servicer.AddAccessToGroup,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessGroupRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessGroupResponse.SerializeToString,
        ),
        "RemoveAccessFromGroup": grpc.unary_unary_rpc_method_handler(
            servicer.RemoveAccessFromGroup,
            request_deserializer=v1_dot_users_dot_user__pb2.AccessGroupRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.AccessGroupResponse.SerializeToString,
        ),
        "AddGroupToUser": grpc.unary_unary_rpc_method_handler(
            servicer.AddGroupToUser,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupUserRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupUserResponse.SerializeToString,
        ),
        "RemoveGroupFromUser": grpc.unary_unary_rpc_method_handler(
            servicer.RemoveGroupFromUser,
            request_deserializer=v1_dot_users_dot_user__pb2.GroupUserRequest.FromString,
            response_serializer=v1_dot_users_dot_user__pb2.GroupUserResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.users.user.UsersService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class UsersService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UserCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserCreate",
            v1_dot_users_dot_user__pb2.UserCreateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserRead",
            v1_dot_users_dot_user__pb2.UserReadRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserUpdate",
            v1_dot_users_dot_user__pb2.UserUpdateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserDelete",
            v1_dot_users_dot_user__pb2.UserDeleteRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserChangePassword(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserChangePassword",
            v1_dot_users_dot_user__pb2.UserChangePasswordRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserChangePasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserChangeEmail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/UserChangeEmail",
            v1_dot_users_dot_user__pb2.UserChangeEmailRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.UserChangeEmailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupCreate",
            v1_dot_users_dot_user__pb2.GroupCreateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupRead",
            v1_dot_users_dot_user__pb2.GroupReadRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupUpdate",
            v1_dot_users_dot_user__pb2.GroupUpdateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GroupDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/GroupDelete",
            v1_dot_users_dot_user__pb2.GroupDeleteRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ActionCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionCreate",
            v1_dot_users_dot_user__pb2.ActionCreateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.ActionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ActionRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionRead",
            v1_dot_users_dot_user__pb2.ActionReadRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.ActionReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ActionUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionUpdate",
            v1_dot_users_dot_user__pb2.ActionUpdateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.ActionUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ActionDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/ActionDelete",
            v1_dot_users_dot_user__pb2.ActionDeleteRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.ActionDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AccessCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessCreate",
            v1_dot_users_dot_user__pb2.AccessCreateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AccessRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessRead",
            v1_dot_users_dot_user__pb2.AccessReadRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AccessUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessUpdate",
            v1_dot_users_dot_user__pb2.AccessUpdateRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AccessDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AccessDelete",
            v1_dot_users_dot_user__pb2.AccessDeleteRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HasPermission(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/HasPermission",
            v1_dot_users_dot_user__pb2.HasPermissionRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.HasPermissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Login(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/Login",
            v1_dot_users_dot_user__pb2.LoginRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RefreshToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/RefreshToken",
            v1_dot_users_dot_user__pb2.RefreshTokenRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.RefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddAccessToGroup(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AddAccessToGroup",
            v1_dot_users_dot_user__pb2.AccessGroupRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessGroupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RemoveAccessFromGroup(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/RemoveAccessFromGroup",
            v1_dot_users_dot_user__pb2.AccessGroupRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.AccessGroupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddGroupToUser(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/AddGroupToUser",
            v1_dot_users_dot_user__pb2.GroupUserRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RemoveGroupFromUser(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.users.user.UsersService/RemoveGroupFromUser",
            v1_dot_users_dot_user__pb2.GroupUserRequest.SerializeToString,
            v1_dot_users_dot_user__pb2.GroupUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import picking_pb2 as v1_dot_stock_dot_picking__pb2


class PickingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PickingCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
        )
        self.PickingRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
        )
        self.PickingUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
        )
        self.PickingDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
        )
        self.ValidatePicking = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ValidatePicking",
            request_serializer=v1_dot_stock_dot_picking__pb2.ValidatePickingRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ValidatePickingResponse.FromString,
        )


class PickingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PickingCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ValidatePicking(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PickingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PickingCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.SerializeToString,
        ),
        "PickingRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.SerializeToString,
        ),
        "PickingUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.SerializeToString,
        ),
        "PickingDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.SerializeToString,
        ),
        "ValidatePicking": grpc.unary_unary_rpc_method_handler(
            servicer.ValidatePicking,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ValidatePickingRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ValidatePickingResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.picking.PickingService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PickingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PickingCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ValidatePicking(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ValidatePicking",
            v1_dot_stock_dot_picking__pb2.ValidatePickingRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ValidatePickingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.stock import location_pb2 as _location_pb2
from omni.pro.protos.v1.stock import sequence_pb2 as _sequence_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class PickingType(_message.Message):
    __slots__ = [
        "id",
        "name",
        "sequence_code",
        "warehouse",
        "code",
        "return_picking_type",
        "show_operations",
        "show_reserved",
        "default_location_src",
        "default_location_dest",
        "sequence",
        "barcode",
        "reservation_method",
        "type_code",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_CODE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    RETURN_PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    SHOW_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    SHOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_SRC_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_DEST_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    BARCODE_FIELD_NUMBER: _ClassVar[int]
    RESERVATION_METHOD_FIELD_NUMBER: _ClassVar[int]
    TYPE_CODE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    sequence_code: str
    warehouse: _base_pb2.ObjectResponse
    code: str
    return_picking_type: _base_pb2.ObjectResponse
    show_operations: _wrappers_pb2.BoolValue
    show_reserved: _wrappers_pb2.BoolValue
    default_location_src: _location_pb2.Location
    default_location_dest: _location_pb2.Location
    sequence: _sequence_pb2.Sequence
    barcode: str
    reservation_method: str
    type_code: str
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        sequence_code: _Optional[str] = ...,
        warehouse: _Optional[_Union[_base_pb2.ObjectResponse, _Mapping]] = ...,
        code: _Optional[str] = ...,
        return_picking_type: _Optional[_Union[_base_pb2.ObjectResponse, _Mapping]] = ...,
        show_operations: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        show_reserved: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        default_location_src: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        default_location_dest: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        sequence: _Optional[_Union[_sequence_pb2.Sequence, _Mapping]] = ...,
        barcode: _Optional[str] = ...,
        reservation_method: _Optional[str] = ...,
        type_code: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "sequence_code",
        "warehouse_id",
        "code",
        "return_picking_type_id",
        "show_operations",
        "show_reserved",
        "default_location_src_id",
        "default_location_dest_id",
        "barcode",
        "reservation_method",
        "type_code",
        "sequence_id",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_CODE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    RETURN_PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    SHOW_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    SHOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_SRC_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_DEST_ID_FIELD_NUMBER: _ClassVar[int]
    BARCODE_FIELD_NUMBER: _ClassVar[int]
    RESERVATION_METHOD_FIELD_NUMBER: _ClassVar[int]
    TYPE_CODE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    sequence_code: str
    warehouse_id: int
    code: str
    return_picking_type_id: int
    show_operations: _wrappers_pb2.BoolValue
    show_reserved: _wrappers_pb2.BoolValue
    default_location_src_id: int
    default_location_dest_id: int
    barcode: str
    reservation_method: str
    type_code: str
    sequence_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        sequence_code: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        return_picking_type_id: _Optional[int] = ...,
        show_operations: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        show_reserved: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        default_location_src_id: _Optional[int] = ...,
        default_location_dest_id: _Optional[int] = ...,
        barcode: _Optional[str] = ...,
        reservation_method: _Optional[str] = ...,
        type_code: _Optional[str] = ...,
        sequence_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeCreateResponse(_message.Message):
    __slots__ = ["response_standard", "picking_type"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    picking_type: PickingType
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "picking_types"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    picking_types: _containers.RepeatedCompositeFieldContainer[PickingType]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        picking_types: _Optional[_Iterable[_Union[PickingType, _Mapping]]] = ...,
    ) -> None: ...

class PickingTypeUpdateRequest(_message.Message):
    __slots__ = ["picking_type", "context"]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    picking_type: PickingType
    context: _base_pb2.Context
    def __init__(
        self,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "picking_type"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    picking_type: PickingType
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class PickingTypeDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_shipper_delivery_method_pb2 as v1_dot_rules_dot_delivery__shipper__delivery__method__pb2,
)


class DeliveryShipperDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryShipperDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.FromString,
        )


class DeliveryShipperDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryShipperDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryShipperDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryShipperDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryShipperDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryShipperDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodCreate",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodRead",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodUpdate",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodDelete",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2


class ModelsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ModelCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelCreate",
            request_serializer=v1_dot_utilities_dot_model__pb2.ModelCreateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_model__pb2.ModelCreateResponse.FromString,
        )
        self.ModelRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelRead",
            request_serializer=v1_dot_utilities_dot_model__pb2.ModelReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_model__pb2.ModelReadResponse.FromString,
        )
        self.ModelUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelUpdate",
            request_serializer=v1_dot_utilities_dot_model__pb2.ModelUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_model__pb2.ModelUpdateResponse.FromString,
        )
        self.ModelDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelDelete",
            request_serializer=v1_dot_utilities_dot_model__pb2.ModelDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_model__pb2.ModelDeleteResponse.FromString,
        )


class ModelsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ModelCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ModelRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ModelUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ModelDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ModelsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ModelCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ModelCreate,
            request_deserializer=v1_dot_utilities_dot_model__pb2.ModelCreateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_model__pb2.ModelCreateResponse.SerializeToString,
        ),
        "ModelRead": grpc.unary_unary_rpc_method_handler(
            servicer.ModelRead,
            request_deserializer=v1_dot_utilities_dot_model__pb2.ModelReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_model__pb2.ModelReadResponse.SerializeToString,
        ),
        "ModelUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ModelUpdate,
            request_deserializer=v1_dot_utilities_dot_model__pb2.ModelUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_model__pb2.ModelUpdateResponse.SerializeToString,
        ),
        "ModelDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ModelDelete,
            request_deserializer=v1_dot_utilities_dot_model__pb2.ModelDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_model__pb2.ModelDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.model.ModelsService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ModelsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ModelCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelCreate",
            v1_dot_utilities_dot_model__pb2.ModelCreateRequest.SerializeToString,
            v1_dot_utilities_dot_model__pb2.ModelCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ModelRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelRead",
            v1_dot_utilities_dot_model__pb2.ModelReadRequest.SerializeToString,
            v1_dot_utilities_dot_model__pb2.ModelReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ModelUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelUpdate",
            v1_dot_utilities_dot_model__pb2.ModelUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_model__pb2.ModelUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ModelDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.model.ModelsService/ModelDelete",
            v1_dot_utilities_dot_model__pb2.ModelDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_model__pb2.ModelDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import (
    territory_matrix_value_pb2 as v1_dot_utilities_dot_territory__matrix__value__pb2,
)


class TerritoryMatrixValueServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TerritoryMatrixValueAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueAdd",
            request_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddResponse.FromString,
        )
        self.TerritoryMatrixValueRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueRead",
            request_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadResponse.FromString,
        )
        self.TerritoryMatrixValueUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueUpdate",
            request_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateResponse.FromString,
        )
        self.TerritoryMatrixValueDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueDelete",
            request_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteResponse.FromString,
        )


class TerritoryMatrixValueServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TerritoryMatrixValueAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixValueRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixValueUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TerritoryMatrixValueDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TerritoryMatrixValueServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "TerritoryMatrixValueAdd": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixValueAdd,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddResponse.SerializeToString,
        ),
        "TerritoryMatrixValueRead": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixValueRead,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadResponse.SerializeToString,
        ),
        "TerritoryMatrixValueUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixValueUpdate,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateResponse.SerializeToString,
        ),
        "TerritoryMatrixValueDelete": grpc.unary_unary_rpc_method_handler(
            servicer.TerritoryMatrixValueDelete,
            request_deserializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TerritoryMatrixValueService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TerritoryMatrixValueAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueAdd",
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixValueRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueRead",
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixValueUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueUpdate",
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TerritoryMatrixValueDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.territory_matrix_value.TerritoryMatrixValueService/TerritoryMatrixValueDelete",
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_territory__matrix__value__pb2.TerritoryMatrixValueDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
